@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: MIDI Utilities
 
-our $VERSION = '0.1001';
+our $VERSION = '0.1002';
 
 use strict;
 use warnings;
@@ -17,7 +17,7 @@ our @EXPORT = qw(
     midi_dump
     midi_format
     set_chan_patch
-    set_time_sig
+    set_time_signature
     setup_score
     dura_size
     ticks
@@ -40,7 +40,7 @@ sub setup_score {
 
     my $score = MIDI::Simple->new_score();
 
-    set_time_sig($score, $args{signature});
+    set_time_signature($score, $args{signature});
 
     $score->set_tempo( bpm_to_ms($args{bpm}) * 1000 );
 
@@ -191,7 +191,7 @@ sub midi_format {
 }
 
 
-sub set_time_sig {
+sub set_time_signature {
     my ($score, $signature) = @_;
     my ($beats, $divisions) = split /\//, $signature;
     $score->time_signature(
@@ -236,11 +236,11 @@ MIDI::Util - MIDI Utilities
 
 =head1 VERSION
 
-version 0.1001
+version 0.1002
 
 =head1 SYNOPSIS
 
-  use MIDI::Util qw(midi_dump midi_format set_chan_patch set_time_sig setup_score);
+  use MIDI::Util qw(midi_dump midi_format set_chan_patch set_time_signature setup_score);
 
   my $dump = midi_dump('volume'); # length, etc.
   print Dumper $dump;
@@ -252,7 +252,7 @@ version 0.1001
   my $ticks = ticks($score);
   my $half = 'd' . ( $size / 2 * $ticks );
 
-  set_time_sig( $score, '5/4' );
+  set_time_signature( $score, '5/4' );
 
   set_chan_patch( $score, 0, 1 );
 
@@ -341,9 +341,9 @@ L<MIDI::Simple>, and L<MIDI::Event> internal lists:
 Change sharp C<#> and flat C<b>, in the list of named notes, to the
 L<MIDI::Simple> C<s> and C<f> respectively.
 
-=head2 set_time_sig
+=head2 set_time_signature
 
-  set_time_sig( $score, $signature );
+  set_time_signature( $score, $signature );
 
 Set the B<score> C<time_signature> based on the given string.
 
